@@ -125,7 +125,7 @@ summarize_mlpmms = function(object, n.cores = 1, verbose = TRUE) {
   if (n.boots > 0) {
     max.cores = parallel::detectCores()
     if (!is.na(max.cores)) {
-      .check_ncores(avail = max.cores, requested = n.cores)
+      .check_ncores(avail = max.cores, requested = n.cores, verbose = verbose)
     }
   }
   
